
EpiScanpy – Epigenomics single cell analysis in python
======================================================

**EpiScanpy** is a toolkit to analyse single-cell open chromatin (scATAC-seq) and single-cell DNA methylation (for example scBS-seq) data. **EpiScanpy** is the epigenomic extension of the very popular scRNA-seq analysis tool **Scanpy** (`Genome Biology <https://doi.org/10.1186/s13059-017-1382-0>`__, 2018) [Wolf18]. For more information on scanpy, read the `documentation <https://scanpy.readthedocs.io>`__. 

EpiScanpy paper is now accessible on `Nature Communications <https://www.nature.com/articles/s41467-021-25131-3>`__. For more information on how to use the package, more information are available on the`website <https://colomemaria.github.io/episcanpy_doc>`__. 


.. start-badges

.. list-table::
    :stub-columns: 1

    * - Releases
      - | |GitHub release| |GitHub tag| |PyPI|
    * - Build status via Conda
      - | |Conda-Linux| 
    * - Python versions
      - | |py39| |py38| |py37| |py36| |py27| 
    * - Operating System
      - | |ubuntu-20.04| |macOS Catalina| |windows-latest|
    * - Document status
      - | |Docs|
    * - Github status
      - | |GitHub contributors| |GitHub stars| |GitHub forks| |GitHub watchers| |GitHub followers| 

.. |Docs| image:: https://readthedocs.com/projects/icb-scanpy/badge/?version=latest
   :target: https://episcanpy.readthedocs.io/en/latest/
.. |PyPI| image:: https://img.shields.io/pypi/v/episcanpy.svg
    :target: https://pypi.org/project/episcanpy
.. |py27| image:: https://github.com/colomemaria/epiScanpy/workflows/py27/badge.svg
    :target: https://github.com/colomemaria/epiScanpy/
.. |py36| image:: https://github.com/colomemaria/epiScanpy/workflows/py36/badge.svg
    :target: https://github.com/colomemaria/epiScanpy/
.. |py37| image:: https://github.com/colomemaria/epiScanpy/workflows/py37/badge.svg
    :target: https://github.com/colomemaria/epiScanpy/
.. |py38| image:: https://github.com/colomemaria/epiScanpy/workflows/py38/badge.svg
    :target: https://github.com/colomemaria/epiScanpy/
.. |py39| image:: https://github.com/colomemaria/epiScanpy/workflows/py39/badge.svg
    :target: https://github.com/colomemaria/epiScanpy/
.. |ubuntu-20.04| image:: https://github.com/colomemaria/epiScanpy/workflows/ubuntu-20.04/badge.svg
    :target: https://github.com/colomemaria/epiScanpy/
.. |macOS Catalina| image:: https://github.com/colomemaria/epiScanpy/workflows/macOS%20Catalina/badge.svg
    :target: https://github.com/colomemaria/epiScanpy/
.. |windows-latest| image:: https://github.com/colomemaria/epiScanpy/workflows/windows-latest/badge.svg
    :target: https://github.com/colomemaria/epiScanpy/
.. |Conda-Linux| image:: https://github.com/colomemaria/epiScanpy/workflows/Conda-Linux/badge.svg
    :target: https://github.com/colomemaria/epiScanpy/
.. |GitHub release| image:: https://img.shields.io/github/release/colomemaria/epiScanpy.svg
   :target: https://GitHub.com/colomemaria/epiScanpy/releases/
.. |GitHub tag| image:: https://img.shields.io/github/tag/colomemaria/epiScanpy.svg
   :target: https://GitHub.com/colomemaria/epiScanpy/tags/
.. |GitHub forks| image:: https://img.shields.io/github/forks/colomemaria/epiScanpy.svg?style=social&label=Fork&maxAge=2592000
   :target: https://GitHub.com/colomemaria/epiScanpy/network/   
.. |GitHub stars| image:: https://img.shields.io/github/stars/colomemaria/epiScanpy.svg?style=social&label=Star&maxAge=2592000
   :target: https://GitHub.com/colomemaria/epiScanpy/stargazers/
.. |GitHub watchers| image:: https://img.shields.io/github/watchers/colomemaria/epiScanpy.svg?style=social&label=Watch&maxAge=2592000
   :target: https://GitHub.com/colomemaria/epiScanpy/watchers/
.. |GitHub followers| image:: https://img.shields.io/github/followers/colomemaria.svg?style=social&label=Follow&maxAge=2592000
   :target: https://GitHub.com/colomemaria?tab=followers
.. |GitHub contributors| image:: https://img.shields.io/github/contributors/colomemaria/epiScanpy.svg
   :target: https://GitHub.com/colomemaria/epiScanpy/graphs/contributors/

Documentation
=============
The documentation for epiScanpy is available `here <https://episcanpy.readthedocs.io/en/latest/>`__. If epiScanpy is useful to your research, consider citing `epiScanpy <https://www.biorxiv.org/content/10.1101/648097v1>`__.



